@@ -161,7 +161,7 @@ func runDashboardCmd(cmd *cobra.Command, args []string) {
 	defer server.Shutdown(dashboardCtx)
 
 	// server has started - update state file/start browser, as required
-	onServerStarted(serverPort, serverListen, initData.Workspace)
+	onServerStarted(dashboardCtx, serverPort, serverListen, initData.Workspace)
 
 	// wait for API server to terminate
 	<-doneChan
@@ -268,7 +268,7 @@ func runSingleDashboard(ctx context.Context, targetName string, inputs map[strin
 	// create context for the dashboard execution
 	ctx = createSnapshotContext(ctx, targetName)
 
-	statushooks.SetStatus(ctx, "Initializing...")
+	statushooks.SetStatus(ctx, "Initializing…")
 	initData := getInitData(ctx)
 
 	statushooks.Done(ctx)
@@ -376,7 +376,7 @@ func setExitCodeForDashboardError(err error) {
 }
 
 // execute any required actions after successful server startup
-func onServerStarted(serverPort dashboardserver.ListenPort, serverListen dashboardserver.ListenType, w *workspace.Workspace) {
+func onServerStarted(ctx context.Context, serverPort dashboardserver.ListenPort, serverListen dashboardserver.ListenType, w *workspace.Workspace) {
 	if isRunningAsService() {
 		// for service mode only, save the state
 		saveDashboardState(serverPort, serverListen)
@@ -385,6 +385,7 @@ func onServerStarted(serverPort dashboardserver.ListenPort, serverListen dashboa
 		if viper.GetBool(constants.ArgBrowser) {
 			url := buildDashboardURL(serverPort, w)
 			if err := utils.OpenBrowser(url); err != nil {
+				dashboardserver.OutputWarning(ctx, "Could not start web browser.")
 				log.Println("[TRACE] dashboard server started but failed to start client", err)
 			}
 		}
