@@ -3,7 +3,6 @@ package cmd
 import (
 	"context"
 	"fmt"
-	"log"
 	"strings"
 	"sync"
 	"time"
@@ -14,13 +13,14 @@ import (
 	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/cmdconfig"
 	"github.com/turbot/steampipe/pkg/constants"
+	"github.com/turbot/steampipe/pkg/contexthelpers"
 	"github.com/turbot/steampipe/pkg/db/db_local"
 	"github.com/turbot/steampipe/pkg/display"
 	"github.com/turbot/steampipe/pkg/error_helpers"
+	"github.com/turbot/steampipe/pkg/installationstate"
 	"github.com/turbot/steampipe/pkg/ociinstaller"
 	"github.com/turbot/steampipe/pkg/ociinstaller/versionfile"
 	"github.com/turbot/steampipe/pkg/plugin"
-	"github.com/turbot/steampipe/pkg/statefile"
 	"github.com/turbot/steampipe/pkg/statushooks"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
@@ -82,11 +82,15 @@ Examples:
   steampipe plugin install aws
 
   # Install a specific plugin version
-  steampipe plugin install turbot/azure@0.1.0`,
+  steampipe plugin install turbot/azure@0.1.0
+
+  # Hide progress bars during installation
+  steampipe plugin install --progress=false aws`,
 	}
 
 	cmdconfig.
 		OnCmd(cmd).
+		AddBoolFlag(constants.ArgProgress, true, "Display installation progress").
 		AddBoolFlag(constants.ArgHelp, false, "Help for plugin install", cmdconfig.FlagOptions.WithShortHand("h"))
 	return cmd
 }
@@ -111,12 +115,16 @@ Examples:
   steampipe plugin update --all
 
   # Update a common plugin (turbot/aws)
-  steampipe plugin update aws`,
+  steampipe plugin update aws
+
+  # Hide progress bars during update
+  steampipe plugin update --progress=false aws`,
 	}
 
 	cmdconfig.
 		OnCmd(cmd).
 		AddBoolFlag(constants.ArgAll, false, "Update all plugins to its latest available version").
+		AddBoolFlag(constants.ArgProgress, true, "Display installation progress").
 		AddBoolFlag(constants.ArgHelp, false, "Help for plugin update", cmdconfig.FlagOptions.WithShortHand("h"))
 
 	return cmd
@@ -201,6 +209,7 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 	// plugin names can be simple names ('aws') for "standard" plugins,
 	// or full refs to the OCI image (us-docker.pkg.dev/steampipe/plugin/turbot/aws:1.0.0)
 	plugins := append([]string{}, args...)
+	showProgress := viper.GetBool(constants.ArgProgress)
 	installReports := make(display.PluginInstallReports, 0, len(plugins))
 
 	if len(plugins) == 0 {
@@ -215,31 +224,49 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 
 	// a leading blank line - since we always output multiple lines
 	fmt.Println()
-
 	progressBars := uiprogress.New()
 	installWaitGroup := &sync.WaitGroup{}
-	dataChannel := make(chan *display.PluginInstallReport, len(plugins))
-
-	progressBars.Start()
+	reportChannel := make(chan *display.PluginInstallReport, len(plugins))
 
+	if showProgress {
+		progressBars.Start()
+	}
 	for _, pluginName := range plugins {
 		installWaitGroup.Add(1)
 		bar := createProgressBar(pluginName, progressBars)
-		go doPluginInstall(ctx, bar, pluginName, installWaitGroup, dataChannel)
+		go doPluginInstall(ctx, bar, pluginName, installWaitGroup, reportChannel)
 	}
 	go func() {
 		installWaitGroup.Wait()
-		close(dataChannel)
+		close(reportChannel)
 	}()
-	for report := range dataChannel {
+	installCount := 0
+	for report := range reportChannel {
 		installReports = append(installReports, report)
+		if !report.Skipped {
+			installCount++
+		} else if !(report.Skipped && report.SkipReason == "Already installed") {
+			exitCode = constants.ExitCodePluginInstallFailure
+		}
+	}
+	if showProgress {
+		progressBars.Stop()
 	}
 
-	progressBars.Stop()
+	if installCount > 0 {
+		// TODO do we need to refresh connections here
 
-	statushooks.SetStatus(ctx, "Refreshing connections...")
-	refreshConnectionsIfNecessary(ctx, installReports, true)
-	statushooks.Done(ctx)
+		// reload the config, since an installation should have created a new config file
+		var cmd = viper.Get(constants.ConfigKeyActiveCommand).(*cobra.Command)
+		config, errorsAndWarnings := steampipeconfig.LoadSteampipeConfig(viper.GetString(constants.ArgModLocation), cmd.Name())
+		if errorsAndWarnings.GetError() != nil {
+			error_helpers.ShowWarning(fmt.Sprintf("Failed to reload config - install report may be incomplete (%s)", errorsAndWarnings.GetError()))
+		} else {
+			steampipeconfig.GlobalConfig = config
+		}
+
+		statushooks.Done(ctx)
+	}
 	display.PrintInstallReports(installReports, false)
 
 	// a concluding blank line - since we always output multiple lines
@@ -255,19 +282,19 @@ func doPluginInstall(ctx context.Context, bar *uiprogress.Bar, pluginName string
 		bar.Set(len(pluginInstallSteps))
 		// let the bar append itself with "Already Installed"
 		bar.AppendFunc(func(b *uiprogress.Bar) string {
-			return helpers.Resize(constants.PluginAlreadyInstalled, 20)
+			return helpers.Resize(constants.InstallMessagePluginAlreadyInstalled, 20)
 		})
 		report = &display.PluginInstallReport{
 			Plugin:         pluginName,
 			Skipped:        true,
-			SkipReason:     constants.PluginAlreadyInstalled,
+			SkipReason:     constants.InstallMessagePluginAlreadyInstalled,
 			IsUpdateReport: false,
 		}
 	} else {
 		// let the bar append itself with the current installation step
 		bar.AppendFunc(func(b *uiprogress.Bar) string {
-			if report != nil && report.SkipReason == constants.PluginNotFound {
-				return helpers.Resize(constants.PluginNotFound, 20)
+			if report != nil && report.SkipReason == constants.InstallMessagePluginNotFound {
+				return helpers.Resize(constants.InstallMessagePluginNotFound, 20)
 			} else {
 				if b.Current() == 0 {
 					// no install step to display yet
@@ -297,6 +324,8 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	// These can be simple names ('aws') for "standard" plugins,
 	// or full refs to the OCI image (us-docker.pkg.dev/steampipe/plugin/turbot/aws:1.0.0)
 	plugins, err := resolveUpdatePluginsFromArgs(args)
+	showProgress := viper.GetBool(constants.ArgProgress)
+
 	if err != nil {
 		fmt.Println()
 		error_helpers.ShowError(ctx, err)
@@ -316,7 +345,7 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 		return
 	}
 
-	state, err := statefile.LoadState()
+	state, err := installationstate.Load()
 	if err != nil {
 		error_helpers.ShowError(ctx, fmt.Errorf("could not load state"))
 		exitCode = constants.ExitCodePluginLoadingError
@@ -358,7 +387,7 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 				updateResults = append(updateResults, &display.PluginInstallReport{
 					Skipped:        true,
 					Plugin:         p,
-					SkipReason:     constants.PluginNotInstalled,
+					SkipReason:     constants.InstallMessagePluginNotInstalled,
 					IsUpdateReport: true,
 				})
 			}
@@ -389,26 +418,35 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	}
 
 	updateWaitGroup := &sync.WaitGroup{}
-	dataChannel := make(chan *display.PluginInstallReport, len(reports))
+	reportChannel := make(chan *display.PluginInstallReport, len(reports))
 	progressBars := uiprogress.New()
-	progressBars.Start()
+	if showProgress {
+		progressBars.Start()
+	}
 
 	sorted := utils.SortedMapKeys(reports)
 	for _, key := range sorted {
 		report := reports[key]
 		updateWaitGroup.Add(1)
-		bar := createProgressBar(report.ShortName(), progressBars)
-		go doPluginUpdate(ctx, bar, report, updateWaitGroup, dataChannel)
+		bar := createProgressBar(report.ShortNameWithStream(), progressBars)
+		go doPluginUpdate(ctx, bar, report, updateWaitGroup, reportChannel)
 	}
 	go func() {
 		updateWaitGroup.Wait()
-		close(dataChannel)
+		close(reportChannel)
 	}()
-	for updateResult := range dataChannel {
+	installCount := 0
+
+	for updateResult := range reportChannel {
 		updateResults = append(updateResults, updateResult)
+		if !updateResult.Skipped {
+			installCount++
+		}
 	}
-	progressBars.Stop()
-	refreshConnectionsIfNecessary(ctx, updateResults, false)
+	if showProgress {
+		progressBars.Stop()
+	}
+
 	display.PrintInstallReports(updateResults, true)
 
 	// a concluding blank line - since we always output multiple lines
@@ -449,7 +487,7 @@ func doPluginUpdate(ctx context.Context, bar *uiprogress.Bar, pvr plugin.Version
 func createProgressBar(plugin string, parentProgressBars *uiprogress.Progress) *uiprogress.Bar {
 	bar := parentProgressBars.AddBar(len(pluginInstallSteps))
 	bar.PrependFunc(func(b *uiprogress.Bar) string {
-		return helpers.Resize(plugin, 20)
+		return helpers.Resize(plugin, 30)
 	})
 	return bar
 }
@@ -476,7 +514,7 @@ func installPlugin(ctx context.Context, pluginName string, isUpdate bool, bar *u
 		_, name, stream := ociinstaller.NewSteampipeImageRef(pluginName).GetOrgNameAndStream()
 		if isPluginNotFoundErr(err) {
 			exitCode = constants.ExitCodePluginNotFound
-			msg = constants.PluginNotFound
+			msg = constants.InstallMessagePluginNotFound
 		} else {
 			msg = err.Error()
 		}
@@ -523,51 +561,11 @@ func resolveUpdatePluginsFromArgs(args []string) ([]string, error) {
 	return plugins, nil
 }
 
-// start service if necessary and refresh connections
-func refreshConnectionsIfNecessary(parentCtx context.Context, reports display.PluginInstallReports, shouldReload bool) error {
-	// get count of skipped reports
-	skipped := 0
-	for _, report := range reports {
-		if report.Skipped {
-			skipped++
-		}
-	}
-	if skipped == len(reports) {
-		// if all were skipped,
-		// no point continuing
-		return nil
-	}
+func runPluginListCmd(cmd *cobra.Command, args []string) {
+	// setup a cancel context and start cancel handler
+	ctx, cancel := context.WithCancel(cmd.Context())
+	contexthelpers.StartCancelHandler(cancel)
 
-	// reload the config, since an installation MUST have created a new config file
-	if shouldReload {
-		var cmd = viper.Get(constants.ConfigKeyActiveCommand).(*cobra.Command)
-		config, err := steampipeconfig.LoadSteampipeConfig(viper.GetString(constants.ArgModLocation), cmd.Name())
-		if err != nil {
-			return err
-		}
-		steampipeconfig.GlobalConfig = config
-	}
-
-	// create a new context with spinner disabled so that
-	// updates from the underlying layers don't end up in the
-	// ui
-	ctx := statushooks.DisableStatusHooks(parentCtx)
-	client, err := db_local.GetLocalClient(ctx, constants.InvokerPlugin, nil)
-	if err != nil {
-		return err
-	}
-	defer client.Close(ctx)
-	res := client.RefreshConnectionAndSearchPaths(ctx)
-	if res.Error != nil {
-		return res.Error
-	}
-	// display any initialisation warnings
-	res.ShowWarnings()
-	return nil
-}
-
-func runPluginListCmd(cmd *cobra.Command, _ []string) {
-	ctx := cmd.Context()
 	utils.LogTime("runPluginListCmd list")
 	defer func() {
 		utils.LogTime("runPluginListCmd end")
@@ -577,59 +575,50 @@ func runPluginListCmd(cmd *cobra.Command, _ []string) {
 		}
 	}()
 
-	pluginConnectionMap, res, err := getPluginConnectionMap(ctx)
-	if err != nil {
-		error_helpers.ShowErrorWithMessage(ctx, err, "plugin listing failed")
+	pluginList, failedPluginMap, missingPluginMap, res := getPluginList(ctx)
+	if res.Error != nil {
+		error_helpers.ShowErrorWithMessage(ctx, res.Error, "plugin listing failed")
 		exitCode = constants.ExitCodePluginListFailure
 		return
 	}
 
-	missingPluginMap := res.Updates.MissingPlugins
-	log.Printf("[TRACE] missing plugins: %v", missingPluginMap)
-
-	list, err := plugin.List(pluginConnectionMap)
-	if err != nil {
-		error_helpers.ShowErrorWithMessage(ctx, err, "plugin listing failed")
-		exitCode = constants.ExitCodePluginListFailure
-		return
-	}
-
-	// If there are missing plugins which have connections left over, list them
-	// along with installed plugins
-	if len(missingPluginMap) != 0 {
-		// List installed plugins
-		if len(list) != 0 {
-			headers := []string{"Installed Plugin", "Version", "Connections"}
-			rows := [][]string{}
-			for _, item := range list {
-				rows = append(rows, []string{item.Name, item.Version, strings.Join(item.Connections, ",")})
-			}
-			display.ShowWrappedTable(headers, rows, &display.ShowWrappedTableOptions{AutoMerge: false})
-			fmt.Printf("\n")
+	// List installed plugins in a table
+	if len(pluginList) != 0 {
+		headers := []string{"Installed Plugin", "Version", "Connections"}
+		var rows [][]string
+		for _, item := range pluginList {
+			rows = append(rows, []string{item.Name, item.Version, strings.Join(item.Connections, ",")})
 		}
+		display.ShowWrappedTable(headers, rows, &display.ShowWrappedTableOptions{AutoMerge: false})
+		fmt.Printf("\n")
+	}
 
-		// List missing plugins
-		headers := []string{"Missing Plugin", "Connections"}
-		var conns = []string{}
+	// List failed/missing plugins in a separate table
+	if len(failedPluginMap)+len(missingPluginMap) != 0 {
+		// List missing/failed plugins
+		headers := []string{"Failed Plugin", "Connections", "Reason"}
+		var conns []string
 		var missingRows [][]string
+
+		// failed plugins
+		for p, item := range failedPluginMap {
+			for _, conn := range item {
+				conns = append(conns, conn.Name)
+			}
+			missingRows = append(missingRows, []string{p, strings.Join(conns, ","), constants.ConnectionErrorPluginFailedToStart})
+			conns = []string{}
+		}
+		// missing plugins
 		for p, item := range missingPluginMap {
 			for _, conn := range item {
 				conns = append(conns, conn.Name)
 			}
-			missingRows = append(missingRows, []string{p, strings.Join(conns, ",")})
+			missingRows = append(missingRows, []string{p, strings.Join(conns, ","), constants.InstallMessagePluginNotInstalled})
 			conns = []string{}
 		}
 		display.ShowWrappedTable(headers, missingRows, &display.ShowWrappedTableOptions{AutoMerge: false})
-	} else {
-		headers := []string{"Installed Plugin", "Version", "Connections"}
-		rows := [][]string{}
-		for _, item := range list {
-			rows = append(rows, []string{item.Name, item.Version, strings.Join(item.Connections, ",")})
-		}
-		display.ShowWrappedTable(headers, rows, &display.ShowWrappedTableOptions{AutoMerge: false})
 	}
 
-	// display any initialisation warnings
 	if len(res.Warnings) > 0 {
 		fmt.Println()
 		res.ShowWarnings()
@@ -637,8 +626,42 @@ func runPluginListCmd(cmd *cobra.Command, _ []string) {
 	}
 }
 
+func getPluginList(ctx context.Context) (pluginList []plugin.PluginListItem, failedPluginMap, missingPluginMap map[string][]*modconfig.Connection, res *modconfig.ErrorAndWarnings) {
+	statushooks.Show(ctx)
+	defer statushooks.Done(ctx)
+
+	// get the maps of available and failed/missing plugins
+	pluginConnectionMap, failedPluginMap, missingPluginMap, res := getPluginConnectionMap(ctx)
+	if res.Error != nil {
+		return nil, nil, nil, res
+	}
+
+	// TODO do we really need to look at installed plugins - can't we just use the plugin connection map
+	// get a list of the installed plugins by inspecting the install location
+	// pass pluginConnectionMap so we can populate the connections for each plugin
+	pluginList, err := plugin.List(pluginConnectionMap)
+	if err != nil {
+		res.Error = err
+		return nil, nil, nil, res
+	}
+
+	// remove the failed plugins from `list` since we don't want them in the installed table
+	for pluginName := range failedPluginMap {
+		for i := 0; i < len(pluginList); i++ {
+			if pluginList[i].Name == pluginName {
+				pluginList = append(pluginList[:i], pluginList[i+1:]...)
+				i-- // Decrement the loop index since we just removed an element
+			}
+		}
+	}
+	return pluginList, failedPluginMap, missingPluginMap, res
+}
+
 func runPluginUninstallCmd(cmd *cobra.Command, args []string) {
-	ctx := cmd.Context()
+	// setup a cancel context and start cancel handler
+	ctx, cancel := context.WithCancel(cmd.Context())
+	contexthelpers.StartCancelHandler(cancel)
+
 	utils.LogTime("runPluginUninstallCmd uninstall")
 
 	defer func() {
@@ -659,9 +682,9 @@ func runPluginUninstallCmd(cmd *cobra.Command, args []string) {
 		return
 	}
 
-	connectionMap, _, err := getPluginConnectionMap(ctx)
-	if err != nil {
-		error_helpers.ShowError(ctx, err)
+	connectionMap, _, _, res := getPluginConnectionMap(ctx)
+	if res.Error != nil {
+		error_helpers.ShowError(ctx, res.Error)
 		exitCode = constants.ExitCodePluginListFailure
 		return
 	}
@@ -684,28 +707,63 @@ func runPluginUninstallCmd(cmd *cobra.Command, args []string) {
 	reports.Print()
 }
 
-func getPluginConnectionMap(ctx context.Context) (map[string][]modconfig.Connection, *steampipeconfig.RefreshConnectionResult, error) {
+func getPluginConnectionMap(ctx context.Context) (pluginConnectionMap, failedPluginMap, missingPluginMap map[string][]*modconfig.Connection, res *modconfig.ErrorAndWarnings) {
 	statushooks.SetStatus(ctx, "Fetching connection map")
-	defer statushooks.Done(ctx)
-	client, err := db_local.GetLocalClient(ctx, constants.InvokerPlugin, nil)
-	if err != nil {
-		return nil, nil, err
+
+	res = &modconfig.ErrorAndWarnings{}
+
+	connectionStateMap, stateRes := getConnectionState(ctx)
+	res.Merge(stateRes)
+	if res.Error != nil {
+		return nil, nil, nil, res
+	}
+
+	// create the map of failed/missing plugins and available/loaded plugins
+	failedPluginMap = map[string][]*modconfig.Connection{}
+	missingPluginMap = map[string][]*modconfig.Connection{}
+	pluginConnectionMap = make(map[string][]*modconfig.Connection)
+
+	for _, state := range connectionStateMap {
+		connection, ok := steampipeconfig.GlobalConfig.Connections[state.ConnectionName]
+		if !ok {
+			continue
+		}
+
+		if state.State == constants.ConnectionStateError && state.Error() == constants.ConnectionErrorPluginFailedToStart {
+			failedPluginMap[state.Plugin] = append(failedPluginMap[state.Plugin], connection)
+		} else if state.State == constants.ConnectionStateError && state.Error() == constants.ConnectionErrorPluginNotInstalled {
+			missingPluginMap[state.Plugin] = append(missingPluginMap[state.Plugin], connection)
+		}
+
+		pluginConnectionMap[state.Plugin] = append(pluginConnectionMap[state.Plugin], connection)
+	}
+
+	return pluginConnectionMap, failedPluginMap, missingPluginMap, res
+}
+
+// load the connection state, waiting until all connections are loaded
+func getConnectionState(ctx context.Context) (steampipeconfig.ConnectionStateMap, *modconfig.ErrorAndWarnings) {
+	// start service
+	client, res := db_local.GetLocalClient(ctx, constants.InvokerPlugin, nil)
+	if res.Error != nil {
+		return nil, res
 	}
 	defer client.Close(ctx)
 
-	res := client.RefreshConnectionAndSearchPaths(statushooks.DisableStatusHooks(ctx))
-	if res.Error != nil {
-		return nil, nil, res.Error
+	conn, err := client.AcquireConnection(ctx)
+	if err != nil {
+		res.Error = err
+		return nil, res
+	}
+	defer conn.Release()
+
+	// load connection state
+	statushooks.SetStatus(ctx, "Loading connection state")
+	connectionStateMap, err := steampipeconfig.LoadConnectionState(ctx, conn.Conn(), steampipeconfig.WithWaitUntilReady())
+	if err != nil {
+		res.Error = err
+		return nil, res
 	}
 
-	pluginConnectionMap := make(map[string][]modconfig.Connection)
-	for _, v := range res.ConnectionMap {
-		_, found := pluginConnectionMap[v.Plugin]
-		if !found {
-			pluginConnectionMap[v.Plugin] = []modconfig.Connection{}
-		}
-		pluginConnectionMap[v.Plugin] = append(pluginConnectionMap[v.Plugin], *v.Connection)
-	}
-
-	return pluginConnectionMap, res, nil
+	return connectionStateMap, res
 }
