@@ -8,6 +8,7 @@ import (
 	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
 
+	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	"github.com/turbot/go-kit/types"
 	"github.com/turbot/steampipe/pkg/constants"
@@ -19,12 +20,12 @@ func Viper() *viper.Viper {
 }
 
 // BootstrapViper sets up viper with the essential path config (workspace-chdir and install-dir)
-func BootstrapViper(loader *steampipeconfig.WorkspaceProfileLoader) error {
+func BootstrapViper(loader *steampipeconfig.WorkspaceProfileLoader, cmd *cobra.Command) error {
 	// set defaults  for keys which do not have a corresponding command flag
 	setBaseDefaults()
 
 	// set defaults from defaultWorkspaceProfile
-	SetDefaultsFromConfig(loader.DefaultProfile.ConfigMap())
+	SetDefaultsFromConfig(loader.DefaultProfile.ConfigMap(cmd))
 
 	// set defaults for install dir and mod location from env vars
 	// this needs to be done since the workspace profile definitions exist in the
@@ -82,14 +83,24 @@ func SetDefaultsFromConfig(configMap map[string]interface{}) {
 }
 
 // for keys which do not have a corresponding command flag, we need a separate defaulting mechanism
+// any option setting, workspace profile property or env var which does not have a command line
+// MUST have a default (unless we want the zero value to take effect)
 func setBaseDefaults() {
 	defaults := map[string]interface{}{
-		constants.ArgUpdateCheck:          true,
-		constants.ArgTelemetry:            constants.TelemetryInfo,
+		// global general options
+		constants.ArgTelemetry:   constants.TelemetryInfo,
+		constants.ArgUpdateCheck: true,
+
+		// workspace profile
+		constants.ArgAutoComplete:  true,
+		constants.ArgIntrospection: constants.IntrospectionNone,
+
+		// from global database options
 		constants.ArgDatabasePort:         constants.DatabaseDefaultPort,
-		constants.ArgMaxCacheSizeMb:       constants.DefaultMaxCacheSizeMb,
-		constants.ArgAutoComplete:         true,
 		constants.ArgDatabaseStartTimeout: constants.DBStartTimeout.Seconds(),
+		constants.ArgServiceCacheEnabled:  true,
+		constants.ArgCacheMaxTtl:          300,
+		constants.ArgMaxCacheSizeMb:       constants.DefaultMaxCacheSizeMb,
 	}
 
 	for k, v := range defaults {
@@ -98,21 +109,20 @@ func setBaseDefaults() {
 }
 
 type envMapping struct {
-	configVar string
-	// "string", "int", "bool"
-	varType string
+	configVar []string
+	varType   EnvVarType
 }
 
 // set default values of INSTALL_DIR and ModLocation from env vars
 func setDirectoryDefaultsFromEnv() {
 	envMappings := map[string]envMapping{
-		constants.EnvInstallDir:     {constants.ArgInstallDir, "string"},
-		constants.EnvWorkspaceChDir: {constants.ArgModLocation, "string"},
-		constants.EnvModLocation:    {constants.ArgModLocation, "string"},
+		constants.EnvInstallDir:     {[]string{constants.ArgInstallDir}, String},
+		constants.EnvWorkspaceChDir: {[]string{constants.ArgModLocation}, String},
+		constants.EnvModLocation:    {[]string{constants.ArgModLocation}, String},
 	}
 
-	for k, v := range envMappings {
-		SetDefaultFromEnv(k, v.configVar, v.varType)
+	for envVar, mapping := range envMappings {
+		setConfigFromEnv(envVar, mapping.configVar, mapping.varType)
 	}
 }
 
@@ -123,38 +133,52 @@ func SetDefaultsFromEnv() {
 
 	// a map of known environment variables to map to viper keys
 	envMappings := map[string]envMapping{
-		constants.EnvInstallDir:           {constants.ArgInstallDir, "string"},
-		constants.EnvWorkspaceChDir:       {constants.ArgModLocation, "string"},
-		constants.EnvModLocation:          {constants.ArgModLocation, "string"},
-		constants.EnvIntrospection:        {constants.ArgIntrospection, "string"},
-		constants.EnvTelemetry:            {constants.ArgTelemetry, "string"},
-		constants.EnvUpdateCheck:          {constants.ArgUpdateCheck, "bool"},
-		constants.EnvCloudHost:            {constants.ArgCloudHost, "string"},
-		constants.EnvCloudToken:           {constants.ArgCloudToken, "string"},
-		constants.EnvSnapshotLocation:     {constants.ArgSnapshotLocation, "string"},
-		constants.EnvWorkspaceDatabase:    {constants.ArgWorkspaceDatabase, "string"},
-		constants.EnvServicePassword:      {constants.ArgServicePassword, "string"},
-		constants.EnvCheckDisplayWidth:    {constants.ArgCheckDisplayWidth, "int"},
-		constants.EnvMaxParallel:          {constants.ArgMaxParallel, "int"},
-		constants.EnvQueryTimeout:         {constants.ArgDatabaseQueryTimeout, "int"},
-		constants.EnvDatabaseStartTimeout: {constants.ArgDatabaseStartTimeout, "int"},
+		constants.EnvInstallDir:           {[]string{constants.ArgInstallDir}, String},
+		constants.EnvWorkspaceChDir:       {[]string{constants.ArgModLocation}, String},
+		constants.EnvModLocation:          {[]string{constants.ArgModLocation}, String},
+		constants.EnvIntrospection:        {[]string{constants.ArgIntrospection}, String},
+		constants.EnvTelemetry:            {[]string{constants.ArgTelemetry}, String},
+		constants.EnvUpdateCheck:          {[]string{constants.ArgUpdateCheck}, Bool},
+		constants.EnvCloudHost:            {[]string{constants.ArgCloudHost}, String},
+		constants.EnvCloudToken:           {[]string{constants.ArgCloudToken}, String},
+		constants.EnvSnapshotLocation:     {[]string{constants.ArgSnapshotLocation}, String},
+		constants.EnvWorkspaceDatabase:    {[]string{constants.ArgWorkspaceDatabase}, String},
+		constants.EnvServicePassword:      {[]string{constants.ArgServicePassword}, String},
+		constants.EnvCheckDisplayWidth:    {[]string{constants.ArgCheckDisplayWidth}, Int},
+		constants.EnvMaxParallel:          {[]string{constants.ArgMaxParallel}, Int},
+		constants.EnvQueryTimeout:         {[]string{constants.ArgDatabaseQueryTimeout}, Int},
+		constants.EnvDatabaseStartTimeout: {[]string{constants.ArgDatabaseStartTimeout}, Int},
+		constants.EnvCacheTTL:             {[]string{constants.ArgCacheTtl}, Int},
+		constants.EnvCacheMaxTTL:          {[]string{constants.ArgCacheMaxTtl}, Int},
+
+		// we need this value to go into different locations
+		constants.EnvCacheEnabled: {[]string{
+			constants.ArgClientCacheEnabled,
+			constants.ArgServiceCacheEnabled,
+		}, Bool},
 	}
 
-	for k, v := range envMappings {
-		SetDefaultFromEnv(k, v.configVar, v.varType)
+	for envVar, v := range envMappings {
+		setConfigFromEnv(envVar, v.configVar, v.varType)
 	}
 }
 
-func SetDefaultFromEnv(k string, configVar string, varType string) {
+func setConfigFromEnv(envVar string, configs []string, varType EnvVarType) {
+	for _, configVar := range configs {
+		SetDefaultFromEnv(envVar, configVar, varType)
+	}
+}
+
+func SetDefaultFromEnv(k string, configVar string, varType EnvVarType) {
 	if val, ok := os.LookupEnv(k); ok {
 		switch varType {
-		case "string":
+		case String:
 			viper.SetDefault(configVar, val)
-		case "bool":
+		case Bool:
 			if boolVal, err := types.ToBool(val); err == nil {
 				viper.SetDefault(configVar, boolVal)
 			}
-		case "int":
+		case Int:
 			if intVal, err := types.ToInt64(val); err == nil {
 				viper.SetDefault(configVar, intVal)
 			}
