@@ -35,6 +35,7 @@ const (
 	ArgProgress             = "progress"
 	ArgExport               = "export"
 	ArgMaxParallel          = "max-parallel"
+	ArgLogLevel             = "log-level"
 	ArgDryRun               = "dry-run"
 	ArgWhere                = "where"
 	ArgTag                  = "tag"
@@ -49,6 +50,10 @@ const (
 	ArgInput                = "input"
 	ArgDashboardInput       = "dashboard-input"
 	ArgMaxCacheSizeMb       = "max-cache-size-mb"
+	ArgCacheTtl             = "cache-ttl"
+	ArgClientCacheEnabled   = "client-cache-enabled"
+	ArgServiceCacheEnabled  = "service-cache-enabled"
+	ArgCacheMaxTtl          = "cache-max-ttl"
 	ArgIntrospection        = "introspection"
 	ArgShare                = "share"
 	ArgSnapshot             = "snapshot"
