@@ -14,25 +14,31 @@ import (
 
 const MaxColumns = 200
 
-type TextFormatter struct{}
+type TextFormatter struct {
+	FormatterBase
+}
 
-func (j *TextFormatter) Format(ctx context.Context, tree *controlexecute.ExecutionTree) (io.Reader, error) {
+func (tf TextFormatter) Format(_ context.Context, tree *controlexecute.ExecutionTree) (io.Reader, error) {
 	renderer := NewTableRenderer(tree)
 	widthConstraint := NewRangeConstraint(renderer.MinimumWidth(), MaxColumns)
-	renderedText := renderer.Render(j.getMaxCols(widthConstraint))
+	renderedText := renderer.Render(tf.getMaxCols(widthConstraint))
 	res := strings.NewReader(fmt.Sprintf("\n%s\n", renderedText))
 	return res, nil
 }
 
-func (j *TextFormatter) FileExtension() string {
-	return ".txt"
+func (tf TextFormatter) FileExtension() string {
+	return constants.TextExtension
 }
 
-func (tf TextFormatter) GetFormatName() string {
-	return "txt"
+func (tf TextFormatter) Name() string {
+	return constants.OutputFormatText
 }
 
-func (j *TextFormatter) getMaxCols(constraint RangeConstraint) int {
+func (tf TextFormatter) Alias() string {
+	return constants.OutputFormatBrief
+}
+
+func (tf TextFormatter) getMaxCols(constraint RangeConstraint) int {
 	colsAvailable, _, _ := gows.GetWinSize()
 	// check if STEAMPIPE_CHECK_DISPLAY_WIDTH env variable is set
 	if viper.IsSet(constants.ArgCheckDisplayWidth) {
