@@ -2,6 +2,7 @@ package dashboardevents
 
 import (
 	"github.com/turbot/steampipe/pkg/control/controlstatus"
+	"time"
 )
 
 type ControlComplete struct {
@@ -10,6 +11,7 @@ type ControlComplete struct {
 	Name        string
 	Session     string
 	ExecutionId string
+	Timestamp   time.Time
 }
 
 // IsDashboardEvent implements DashboardEvent interface
