@@ -7,6 +7,7 @@ import (
 	"github.com/jackc/pgx/v5"
 	"github.com/jackc/pgx/v5/pgxpool"
 	"github.com/spf13/viper"
+	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/constants/runtime"
 	"github.com/turbot/steampipe/pkg/db/db_common"
@@ -18,22 +19,34 @@ type DbConnectionCallback func(context.Context, *pgx.Conn) error
 func (c *DbClient) establishConnectionPool(ctx context.Context) error {
 	utils.LogTime("db_client.establishConnectionPool start")
 	defer utils.LogTime("db_client.establishConnectionPool end")
+
 	const (
 		connMaxIdleTime = 1 * time.Minute
 		connMaxLifetime = 10 * time.Minute
 	)
-	minConnections := 2
-	maxConnections := maxDbConnections()
-	if minConnections > maxConnections {
-		minConnections = maxConnections
-	}
+	maxConnections := db_common.MaxDbConnections()
 
 	config, err := pgxpool.ParseConfig(c.connectionString)
 	if err != nil {
 		return err
 	}
+
+	locals := []string{
+		"127.0.0.1",
+		"::1",
+		"localhost",
+	}
+
+	if helpers.StringSliceContains(locals, config.ConnConfig.Host) {
+		c.isLocalService = true
+	}
+
+	// MinConns should default to 0, but when not set, it actually get very high values (e.g. 80217984)
+	// this leads to a huge number of connections getting created
+	// TODO BINAEK dig into this and figure out why this is happening.
+	// We need to be sure that it is not an issue with service management
+	config.MinConns = 0
 	config.MaxConns = int32(maxConnections)
-	config.MinConns = int32(minConnections)
 	config.MaxConnLifetime = connMaxLifetime
 	config.MaxConnIdleTime = connMaxIdleTime
 	if c.onConnectionCallback != nil {
@@ -63,11 +76,3 @@ func (c *DbClient) establishConnectionPool(ctx context.Context) error {
 	c.pool = dbPool
 	return nil
 }
-
-func maxDbConnections() int {
-	maxParallel := constants.DefaultMaxConnections
-	if viper.IsSet(constants.ArgMaxParallel) {
-		maxParallel = viper.GetInt(constants.ArgMaxParallel)
-	}
-	return maxParallel
-}
