@@ -4,16 +4,25 @@ import (
 	"context"
 	"fmt"
 	"log"
+	"time"
 
 	"github.com/jackc/pgx/v5/pgxpool"
 	"github.com/spf13/viper"
-	"github.com/turbot/steampipe/pkg/cmdconfig"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
-	"github.com/turbot/steampipe/pkg/steampipeconfig"
-	"github.com/turbot/steampipe/pkg/utils"
 )
 
+func (c *DbClient) AcquireConnection(ctx context.Context) (*pgxpool.Conn, error) {
+	// get a database connection and query its backend pid
+	// note - this will retry if the connection is bad
+	conn, _, err := c.GetDatabaseConnectionWithRetries(ctx)
+	if err != nil {
+		return nil, err
+	}
+
+	return conn, nil
+}
+
 func (c *DbClient) AcquireSession(ctx context.Context) (sessionResult *db_common.AcquireSessionResult) {
 	sessionResult = &db_common.AcquireSessionResult{}
 
@@ -29,27 +38,9 @@ func (c *DbClient) AcquireSession(ctx context.Context) (sessionResult *db_common
 		}
 	}()
 
-	// save the current value of schema names, then reload the names and check for differences
-	schemaNames := c.AllSchemaNames()
-
-	// reload schema names in case they changed based on a connection watcher event
-	if err := c.LoadSchemaNames(ctx); err != nil {
-		sessionResult.Error = err
-		return
-	}
-
-	// if the schemas have changes, reset the desired search path
-	newSchemaNames := c.AllSchemaNames()
-	if !utils.StringSlicesEqual(schemaNames, newSchemaNames) {
-		if err := c.updateRequiredSearchPath(ctx); err != nil {
-			sessionResult.Error = err
-			return
-		}
-	}
-
 	// get a database connection and query its backend pid
 	// note - this will retry if the connection is bad
-	databaseConnection, backendPid, err := c.getDatabaseConnectionWithRetries(ctx)
+	databaseConnection, backendPid, err := c.GetDatabaseConnectionWithRetries(ctx)
 	if err != nil {
 		sessionResult.Error = err
 		return sessionResult
@@ -69,10 +60,38 @@ func (c *DbClient) AcquireSession(ctx context.Context) (sessionResult *db_common
 	// make sure that we close the acquired session, in case of error
 	defer func() {
 		if sessionResult.Error != nil && databaseConnection != nil {
+			sessionResult.Session = nil
 			databaseConnection.Release()
 		}
 	}()
 
+	// if this is connected to a local service (localhost) and if the server cache
+	// is disabled, override the client setting to always disable
+	//
+	// this is a temporary workaround to make sure
+	// that we turn off caching for plugins compiled with SDK pre-V5
+	if c.isLocalService && !viper.GetBool(constants.ArgServiceCacheEnabled) {
+		if err := db_common.SetCacheEnabled(ctx, false, databaseConnection.Conn()); err != nil {
+			sessionResult.Error = err
+			return sessionResult
+		}
+	} else {
+		if viper.IsSet(constants.ArgClientCacheEnabled) {
+			if err := db_common.SetCacheEnabled(ctx, viper.GetBool(constants.ArgClientCacheEnabled), databaseConnection.Conn()); err != nil {
+				sessionResult.Error = err
+				return sessionResult
+			}
+		}
+	}
+
+	if viper.IsSet(constants.ArgCacheTtl) {
+		ttl := time.Duration(viper.GetInt(constants.ArgCacheTtl)) * time.Second
+		if err := db_common.SetCacheTtl(ctx, ttl, databaseConnection.Conn()); err != nil {
+			sessionResult.Error = err
+			return sessionResult
+		}
+	}
+
 	// update required session search path if needed
 	err = c.ensureSessionSearchPath(ctx, session)
 	if err != nil {
@@ -84,28 +103,14 @@ func (c *DbClient) AcquireSession(ctx context.Context) (sessionResult *db_common
 	return sessionResult
 }
 
-// reload Steampipe config, update viper and re-set required search path
-func (c *DbClient) updateRequiredSearchPath(ctx context.Context) error {
-	config, err := steampipeconfig.LoadSteampipeConfig(viper.GetString(constants.ArgModLocation), "dashboard")
-	if err != nil {
-		return err
-	}
-	steampipeconfig.GlobalConfig = config
-	cmdconfig.SetDefaultsFromConfig(steampipeconfig.GlobalConfig.ConfigMap())
-	if err := c.SetRequiredSessionSearchPath(ctx); err != nil {
-		return err
-	}
-	return nil
-}
-
-func (c *DbClient) getDatabaseConnectionWithRetries(ctx context.Context) (*pgxpool.Conn, uint32, error) {
+func (c *DbClient) GetDatabaseConnectionWithRetries(ctx context.Context) (*pgxpool.Conn, uint32, error) {
 	// get a database connection from the pool
 	databaseConnection, err := c.pool.Acquire(ctx)
 	if err != nil {
 		if databaseConnection != nil {
 			databaseConnection.Release()
 		}
-		log.Printf("[TRACE] getDatabaseConnectionWithRetries failed: %s", err.Error())
+		log.Printf("[TRACE] GetDatabaseConnectionWithRetries failed: %s", err.Error())
 		return nil, 0, err
 	}
 
