@@ -26,41 +26,12 @@ import (
 	"golang.org/x/text/message"
 )
 
-type DisplayConfiguration struct {
-	timing bool
-}
-
-type DisplayOption = func(config *DisplayConfiguration)
-
-// ShowTimingOnOutput only enables timing if the current output mode is the one provided and if --timing is set
-func ShowTimingOnOutput(output string) DisplayOption {
-	return func(o *DisplayConfiguration) {
-		o.timing = o.timing && (cmdconfig.Viper().GetString(constants.ArgOutput) == output)
-	}
-}
-
-// DisableTiming disables display of timing data forcefully
-func DisableTiming() DisplayOption {
-	return func(o *DisplayConfiguration) {
-		o.timing = false
-	}
-}
-
-// EnableTiming enables display of timing data forcefully
-func EnableTiming() DisplayOption {
-	return func(o *DisplayConfiguration) {
-		o.timing = true
-	}
-}
-
 // ShowOutput displays the output using the proper formatter as applicable
 func ShowOutput(ctx context.Context, result *queryresult.Result, opts ...DisplayOption) int {
 	rowErrors := 0
-	options := &DisplayConfiguration{
-		timing: cmdconfig.Viper().GetBool(constants.ArgTiming),
-	}
+	config := NewDisplayConfiguration()
 	for _, o := range opts {
-		o(options)
+		o(config)
 	}
 
 	switch cmdconfig.Viper().GetString(constants.ArgOutput) {
@@ -74,7 +45,7 @@ func ShowOutput(ctx context.Context, result *queryresult.Result, opts ...Display
 		rowErrors = displayTable(ctx, result)
 	}
 
-	if options.timing {
+	if config.timing {
 		fmt.Println(buildTimingString(result))
 	}
 	// return the number of rows that returned errors
