@@ -1,56 +1,84 @@
 package modinstaller
 
 import (
+	"context"
 	"fmt"
 	"log"
 	"os"
+	"path"
 	"path/filepath"
 
-	"github.com/Masterminds/semver"
+	"github.com/Masterminds/semver/v3"
 	git "github.com/go-git/go-git/v5"
 	"github.com/otiai10/copy"
 	"github.com/spf13/viper"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/filepaths"
+	"github.com/turbot/steampipe/pkg/plugin"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/parse"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/versionmap"
 	"github.com/turbot/steampipe/pkg/utils"
+	"github.com/turbot/steampipe/sperr"
 )
 
 type ModInstaller struct {
-	workspaceMod *modconfig.Mod
-	modsPath     string
-	// temp location used to install dependencies
-	tmpPath       string
-	workspacePath string
-
 	installData *InstallData
 
+	// this will be updated as changes are made to dependencies
+	workspaceMod *modconfig.Mod
+
+	// since changes are made to workspaceMod, we need a copy of the Require as is on disk
+	// to be able to calculate changes
+	oldRequire *modconfig.Require
+
+	// installed plugins
+	installedPlugins map[string]*semver.Version
+
+	mods versionmap.VersionConstraintMap
+
+	// the final resting place of all dependency mods
+	modsPath string
+	// a shadow directory for installing mods
+	// this is necessary to make mod installation transactional
+	shadowDirPath string
+
+	workspacePath string
+
 	// what command is being run
 	command string
 	// are dependencies being added to the workspace
-	mods   versionmap.VersionConstraintMap
 	dryRun bool
+	// do we force install even if there are require errors
+	force bool
 }
 
 func NewModInstaller(opts *InstallOpts) (*ModInstaller, error) {
+	if opts.WorkspaceMod == nil {
+		return nil, sperr.New("no workspace mod passed to mod installer")
+	}
 	i := &ModInstaller{
-		workspacePath: opts.WorkspacePath,
+		workspacePath: opts.WorkspaceMod.ModPath,
+		workspaceMod:  opts.WorkspaceMod,
 		command:       opts.Command,
 		dryRun:        opts.DryRun,
+		force:         opts.Force,
 	}
+
+	if opts.WorkspaceMod.Require != nil {
+		i.oldRequire = opts.WorkspaceMod.Require.Clone()
+	}
+
 	if err := i.setModsPath(); err != nil {
 		return nil, err
 	}
 
-	// load workspace mod, creating a default if needed
-	workspaceMod, err := i.loadModfile(i.workspacePath, true)
+	installedPlugins, err := plugin.GetInstalledPlugins()
 	if err != nil {
 		return nil, err
 	}
-	i.workspaceMod = workspaceMod
+	i.installedPlugins = installedPlugins
 
 	// load lock file
 	workspaceLock, err := versionmap.LoadWorkspaceLock(i.workspacePath)
@@ -59,7 +87,7 @@ func NewModInstaller(opts *InstallOpts) (*ModInstaller, error) {
 	}
 
 	// create install data
-	i.installData = NewInstallData(workspaceLock, workspaceMod)
+	i.installData = NewInstallData(workspaceLock, i.workspaceMod)
 
 	// parse args to get the required mod versions
 	requiredMods, err := i.GetRequiredModVersionsFromArgs(opts.ModArgs)
@@ -71,17 +99,33 @@ func NewModInstaller(opts *InstallOpts) (*ModInstaller, error) {
 	return i, nil
 }
 
-func (i *ModInstaller) setModsPath() error {
-	dir, err := os.MkdirTemp(os.TempDir(), "sp_dr_*")
+func (i *ModInstaller) removeOldShadowDirectories() error {
+	removeErrors := []error{}
+	// get the parent of the 'mods' directory - all shadow directories are siblings of this
+	parent := filepath.Base(i.modsPath)
+	entries, err := os.ReadDir(parent)
 	if err != nil {
 		return err
 	}
-	i.tmpPath = dir
+	for _, dir := range entries {
+		if dir.IsDir() && filepaths.IsModInstallShadowPath(dir.Name()) {
+			err := os.RemoveAll(filepath.Join(parent, dir.Name()))
+			if err != nil {
+				removeErrors = append(removeErrors, err)
+			}
+		}
+	}
+	return error_helpers.CombineErrors(removeErrors...)
+}
+
+func (i *ModInstaller) setModsPath() error {
 	i.modsPath = filepaths.WorkspaceModPath(i.workspacePath)
+	_ = i.removeOldShadowDirectories()
+	i.shadowDirPath = filepaths.WorkspaceModShadowPath(i.workspacePath)
 	return nil
 }
 
-func (i *ModInstaller) UninstallWorkspaceDependencies() error {
+func (i *ModInstaller) UninstallWorkspaceDependencies(ctx context.Context) error {
 	workspaceMod := i.workspaceMod
 
 	// remove required dependencies from the mod file
@@ -94,7 +138,7 @@ func (i *ModInstaller) UninstallWorkspaceDependencies() error {
 	}
 
 	// uninstall by calling Install
-	if err := i.installMods(workspaceMod.Require.Mods, workspaceMod); err != nil {
+	if err := i.installMods(ctx, workspaceMod.Require.Mods, workspaceMod); err != nil {
 		return err
 	}
 
@@ -104,7 +148,6 @@ func (i *ModInstaller) UninstallWorkspaceDependencies() error {
 
 	// if this is a dry run, return now
 	if i.dryRun {
-
 		log.Printf("[TRACE] UninstallWorkspaceDependencies - dry-run=true, returning before saving mod file and cache\n")
 		return nil
 	}
@@ -115,7 +158,7 @@ func (i *ModInstaller) UninstallWorkspaceDependencies() error {
 	}
 
 	//  now safe to save the mod file
-	if err := i.workspaceMod.Save(); err != nil {
+	if err := i.updateModFile(); err != nil {
 		return err
 	}
 
@@ -129,12 +172,17 @@ func (i *ModInstaller) UninstallWorkspaceDependencies() error {
 }
 
 // InstallWorkspaceDependencies installs all dependencies of the workspace mod
-func (i *ModInstaller) InstallWorkspaceDependencies() (err error) {
+func (i *ModInstaller) InstallWorkspaceDependencies(ctx context.Context) (err error) {
 	workspaceMod := i.workspaceMod
 	defer func() {
+		if err != nil && i.force {
+			// suppress the error since this is a forced install
+			log.Println("[TRACE] suppressing error in InstallWorkspaceDependencies because force is enabled", err)
+			err = nil
+		}
 		// tidy unused mods
 		// (put in defer so it still gets called in case of errors)
-		if viper.GetBool(constants.ArgPrune) {
+		if viper.GetBool(constants.ArgPrune) && !i.dryRun {
 			// be sure not to overwrite an existing return error
 			_, pruneErr := i.Prune()
 			if pruneErr != nil && err == nil {
@@ -143,9 +191,14 @@ func (i *ModInstaller) InstallWorkspaceDependencies() (err error) {
 		}
 	}()
 
-	// first check our Steampipe version is sufficient
-	if err := workspaceMod.Require.ValidateSteampipeVersion(workspaceMod.Name()); err != nil {
-		return err
+	if validationErrors := workspaceMod.ValidateRequirements(i.installedPlugins); len(validationErrors) > 0 {
+		if !i.force {
+			// if this is not a force install, return errors in validation
+			return error_helpers.CombineErrors(validationErrors...)
+		}
+		// ignore if this is a force install
+		// TODO: raise warnings for errors getting suppressed [https://github.com/turbot/steampipe/issues/3364]
+		log.Println("[TRACE] suppressing mod validation error", validationErrors)
 	}
 
 	// if mod args have been provided, add them to the the workspace mod requires
@@ -154,7 +207,7 @@ func (i *ModInstaller) InstallWorkspaceDependencies() (err error) {
 		workspaceMod.AddModDependencies(i.mods)
 	}
 
-	if err := i.installMods(workspaceMod.Require.Mods, workspaceMod); err != nil {
+	if err := i.installMods(ctx, workspaceMod.Require.Mods, workspaceMod); err != nil {
 		return err
 	}
 
@@ -170,10 +223,8 @@ func (i *ModInstaller) InstallWorkspaceDependencies() (err error) {
 	}
 
 	//  now safe to save the mod file
-	if len(i.mods) > 0 {
-		if err := i.workspaceMod.Save(); err != nil {
-			return err
-		}
+	if err := i.updateModFile(); err != nil {
+		return err
 	}
 
 	if !workspaceMod.HasDependentMods() {
@@ -184,16 +235,75 @@ func (i *ModInstaller) InstallWorkspaceDependencies() (err error) {
 }
 
 func (i *ModInstaller) GetModList() string {
-	return i.installData.Lock.GetModList(i.workspaceMod.GetModDependencyPath())
+	return i.installData.Lock.GetModList(i.workspaceMod.GetInstallCacheKey())
 }
 
-func (i *ModInstaller) installMods(mods []*modconfig.ModVersionConstraint, parent *modconfig.Mod) error {
-	// clean up the temp location
-	defer os.RemoveAll(i.tmpPath)
+// commitShadow recursively copies over the contents of the shadow directory
+// to the mods directory, replacing conflicts as it goes
+// (uses `os.Create(dest)` under the hood - which truncates the target)
+func (i *ModInstaller) commitShadow(ctx context.Context) error {
+	if error_helpers.IsContextCanceled(ctx) {
+		return ctx.Err()
+	}
+	if _, err := os.Stat(i.shadowDirPath); os.IsNotExist(err) {
+		// nothing to do here
+		// there's no shadow directory to commit
+		// this is not an error and may happen when install does not make any changes
+		return nil
+	}
+	entries, err := os.ReadDir(i.shadowDirPath)
+	if err != nil {
+		return sperr.WrapWithRootMessage(err, "could not read shadow directory")
+	}
+	for _, entry := range entries {
+		if !entry.IsDir() {
+			continue
+		}
+		source := filepath.Join(i.shadowDirPath, entry.Name())
+		destination := filepath.Join(i.modsPath, entry.Name())
+		log.Println("[TRACE] copying", source, destination)
+		if err := copy.Copy(source, destination); err != nil {
+			return sperr.WrapWithRootMessage(err, "could not commit shadow directory '%s'", entry.Name())
+		}
+	}
+	return nil
+}
+
+func (i *ModInstaller) shouldCommitShadow(ctx context.Context, installError error) bool {
+	// no commit if this is a dry run
+	if i.dryRun {
+		return false
+	}
+	// commit if this is forced - even if there's errors
+	return installError == nil || i.force
+}
+
+func (i *ModInstaller) installMods(ctx context.Context, mods []*modconfig.ModVersionConstraint, parent *modconfig.Mod) (err error) {
+	defer func() {
+		var commitErr error
+		if i.shouldCommitShadow(ctx, err) {
+			commitErr = i.commitShadow(ctx)
+		}
+
+		// if this was forced, we need to suppress the install error
+		// otherwise the calling code will fail
+		if i.force {
+			err = nil
+		}
+
+		// ensure we return any commit error
+		if commitErr != nil {
+			err = commitErr
+		}
+
+		// force remove the shadow directory - we can ignore any error here, since
+		// these directories get cleaned up before any install session
+		os.RemoveAll(i.shadowDirPath)
+	}()
 
 	var errors []error
 	for _, requiredModVersion := range mods {
-		modToUse, err := i.getCurrentlyInstalledVersionToUse(requiredModVersion, parent, i.updating())
+		modToUse, err := i.getCurrentlyInstalledVersionToUse(ctx, requiredModVersion, parent, i.updating())
 		if err != nil {
 			errors = append(errors, err)
 			continue
@@ -202,7 +312,7 @@ func (i *ModInstaller) installMods(mods []*modconfig.ModVersionConstraint, paren
 		// if the mod is not installed or needs updating, pass shouldUpdate=true into installModDependencesRecursively
 		// this ensures that we update any dependencies which have updates available
 		shouldUpdate := modToUse == nil
-		if err := i.installModDependencesRecursively(requiredModVersion, modToUse, parent, shouldUpdate); err != nil {
+		if err := i.installModDependencesRecursively(ctx, requiredModVersion, modToUse, parent, shouldUpdate); err != nil {
 			errors = append(errors, err)
 		}
 	}
@@ -226,7 +336,11 @@ func (i *ModInstaller) buildInstallError(errors []error) error {
 	return err
 }
 
-func (i *ModInstaller) installModDependencesRecursively(requiredModVersion *modconfig.ModVersionConstraint, dependencyMod *modconfig.Mod, parent *modconfig.Mod, shouldUpdate bool) error {
+func (i *ModInstaller) installModDependencesRecursively(ctx context.Context, requiredModVersion *modconfig.ModVersionConstraint, dependencyMod *modconfig.Mod, parent *modconfig.Mod, shouldUpdate bool) error {
+	if error_helpers.IsContextCanceled(ctx) {
+		// short circuit if the execution context has been cancelled
+		return ctx.Err()
+	}
 	// get available versions for this mod
 	includePrerelease := requiredModVersion.Constraint.IsPrerelease()
 	availableVersions, err := i.installData.getAvailableModVersions(requiredModVersion.Name, includePrerelease)
@@ -235,9 +349,9 @@ func (i *ModInstaller) installModDependencesRecursively(requiredModVersion *modc
 		return err
 	}
 
-	if dependencyMod == nil {
-		// so we ARE installing
+	var errors []error
 
+	if dependencyMod == nil {
 		// get a resolved mod ref that satisfies the version constraints
 		resolvedRef, err := i.getModRefSatisfyingConstraints(requiredModVersion, availableVersions)
 		if err != nil {
@@ -245,16 +359,14 @@ func (i *ModInstaller) installModDependencesRecursively(requiredModVersion *modc
 		}
 
 		// install the mod
-		dependencyMod, err = i.install(resolvedRef, parent)
+		dependencyMod, err = i.install(ctx, resolvedRef, parent)
 		if err != nil {
 			return err
 		}
-		if err = dependencyMod.ValidateSteampipeVersion(); err != nil {
-			return err
-		}
-	} else {
-		// so we found an existing mod which will satisfy this requirement
 
+		validationErrors := dependencyMod.ValidateRequirements(i.installedPlugins)
+		errors = append(errors, validationErrors...)
+	} else {
 		// update the install data
 		i.installData.addExisting(requiredModVersion.Name, dependencyMod, requiredModVersion.Constraint, parent)
 		log.Printf("[TRACE] not installing %s with version constraint %s as version %s is already installed", requiredModVersion.Name, requiredModVersion.Constraint.Original, dependencyMod.Version)
@@ -262,16 +374,13 @@ func (i *ModInstaller) installModDependencesRecursively(requiredModVersion *modc
 
 	// to get here we have the dependency mod - either we installed it or it was already installed
 	// recursively install its dependencies
-	var errors []error
-	// now update the parent to dependency mod and install its child dependencies
-	parent = dependencyMod
-	for _, dep := range dependencyMod.Require.Mods {
-		childDependencyMod, err := i.getCurrentlyInstalledVersionToUse(dep, parent, shouldUpdate)
+	for _, childDependency := range dependencyMod.Require.Mods {
+		childDependencyMod, err := i.getCurrentlyInstalledVersionToUse(ctx, childDependency, dependencyMod, shouldUpdate)
 		if err != nil {
 			errors = append(errors, err)
 			continue
 		}
-		if err := i.installModDependencesRecursively(dep, childDependencyMod, parent, shouldUpdate); err != nil {
+		if err := i.installModDependencesRecursively(ctx, childDependency, childDependencyMod, dependencyMod, shouldUpdate); err != nil {
 			errors = append(errors, err)
 			continue
 		}
@@ -280,7 +389,7 @@ func (i *ModInstaller) installModDependencesRecursively(requiredModVersion *modc
 	return error_helpers.CombineErrorsWithPrefix(fmt.Sprintf("%d child %s failed to install", len(errors), utils.Pluralize("dependency", len(errors))), errors...)
 }
 
-func (i *ModInstaller) getCurrentlyInstalledVersionToUse(requiredModVersion *modconfig.ModVersionConstraint, parent *modconfig.Mod, forceUpdate bool) (*modconfig.Mod, error) {
+func (i *ModInstaller) getCurrentlyInstalledVersionToUse(ctx context.Context, requiredModVersion *modconfig.ModVersionConstraint, parent *modconfig.Mod, forceUpdate bool) (*modconfig.Mod, error) {
 	// do we have an installed version of this mod matching the required mod constraint
 	installedVersion, err := i.installData.Lock.GetLockedModVersion(requiredModVersion, parent)
 	if err != nil {
@@ -302,7 +411,51 @@ func (i *ModInstaller) getCurrentlyInstalledVersionToUse(requiredModVersion *mod
 	}
 
 	// load the existing mod and return
-	return i.loadDependencyMod(installedVersion)
+	return i.loadDependencyMod(ctx, installedVersion)
+}
+
+// loadDependencyMod tries to load the mod definition from the shadow directory
+// and falls back to the 'mods' directory of the root mod
+func (i *ModInstaller) loadDependencyMod(ctx context.Context, modVersion *versionmap.ResolvedVersionConstraint) (*modconfig.Mod, error) {
+	// construct the dependency path - this is the relative path of the dependency we are installing
+	dependencyPath := modVersion.DependencyPath()
+
+	// first try loading from the shadow dir
+	modDefinition, err := i.loadDependencyModFromRoot(ctx, i.shadowDirPath, dependencyPath)
+	if err != nil {
+		return nil, err
+	}
+
+	// failed to load from shadow dir, try mods dir
+	if modDefinition == nil {
+		modDefinition, err = i.loadDependencyModFromRoot(ctx, i.modsPath, dependencyPath)
+		if err != nil {
+			return nil, err
+		}
+	}
+
+	// if we still failed, give up
+	if modDefinition == nil {
+		return nil, fmt.Errorf("could not find dependency mod '%s'", dependencyPath)
+	}
+
+	// set the DependencyName, DependencyPath and Version properties on the mod
+	if err := i.setModDependencyConfig(modDefinition, dependencyPath); err != nil {
+		return nil, err
+	}
+
+	return modDefinition, nil
+}
+
+func (i *ModInstaller) loadDependencyModFromRoot(ctx context.Context, modInstallRoot string, dependencyPath string) (*modconfig.Mod, error) {
+	log.Printf("[TRACE] loadDependencyModFromRoot: trying to load %s from root %s", dependencyPath, modInstallRoot)
+
+	modPath := path.Join(modInstallRoot, dependencyPath)
+	modDefinition, err := parse.LoadModfile(modPath)
+	if err != nil {
+		return nil, sperr.WrapWithMessage(err, "failed to load mod definition for %s from %s", dependencyPath, modInstallRoot)
+	}
+	return modDefinition, nil
 }
 
 // determine if we should update this mod, and if so whether there is an update available
@@ -348,11 +501,11 @@ func (i *ModInstaller) getModRefSatisfyingConstraints(modVersion *modconfig.ModV
 }
 
 // install a mod
-func (i *ModInstaller) install(dependency *ResolvedModRef, parent *modconfig.Mod) (_ *modconfig.Mod, err error) {
+func (i *ModInstaller) install(ctx context.Context, dependency *ResolvedModRef, parent *modconfig.Mod) (_ *modconfig.Mod, err error) {
 	var modDef *modconfig.Mod
 	// get the temp location to install the mod to
-	fullName := dependency.FullName()
-	tempDestPath := i.getDependencyTmpPath(fullName)
+	dependencyPath := dependency.DependencyPath()
+	destPath := i.getDependencyShadowPath(dependencyPath)
 
 	defer func() {
 		if err == nil {
@@ -361,29 +514,25 @@ func (i *ModInstaller) install(dependency *ResolvedModRef, parent *modconfig.Mod
 	}()
 	// if the target path exists, use the exiting file
 	// if it does not exist (the usual case), install it
-	if _, err := os.Stat(tempDestPath); os.IsNotExist(err) {
-		if err := i.installFromGit(dependency, tempDestPath); err != nil {
+	if _, err := os.Stat(destPath); os.IsNotExist(err) {
+		log.Println("[TRACE] installing", dependencyPath, "in", destPath)
+		if err := i.installFromGit(dependency, destPath); err != nil {
 			return nil, err
 		}
 	}
 
 	// now load the installed mod and return it
-	modDef, err = i.loadModfile(tempDestPath, false)
+	modDef, err = parse.LoadModfile(destPath)
 	if err != nil {
 		return nil, err
 	}
 	if modDef == nil {
-		return nil, fmt.Errorf("'%s' has no mod definition file", dependency.FullName())
+		return nil, fmt.Errorf("'%s' has no mod definition file", dependencyPath)
 	}
 
-	// so we have successfully installed this dependency to the temp location, now copy to the mod location
 	if !i.dryRun {
-		destPath := i.getDependencyDestPath(fullName)
-		if err := i.copyModFromTempToModsFolder(tempDestPath, destPath); err != nil {
-			return nil, err
-		}
-		// now the mod is installed in it's final location, set mod dependency path
-		if err := i.setModDependencyPath(modDef, destPath); err != nil {
+		// now the mod is installed in its final location, set mod dependency path
+		if err := i.setModDependencyConfig(modDef, dependencyPath); err != nil {
 			return nil, err
 		}
 	}
@@ -391,20 +540,10 @@ func (i *ModInstaller) install(dependency *ResolvedModRef, parent *modconfig.Mod
 	return modDef, nil
 }
 
-func (i *ModInstaller) copyModFromTempToModsFolder(tmpPath string, destPath string) error {
-	if err := os.RemoveAll(destPath); err != nil {
-		return err
-	}
-
-	if err := copy.Copy(tmpPath, destPath); err != nil {
-		return err
-	}
-	return nil
-}
-
 func (i *ModInstaller) installFromGit(dependency *ResolvedModRef, installPath string) error {
 	// get the mod from git
 	gitUrl := getGitUrl(dependency.Name)
+	log.Println("[TRACE] >>> cloning", gitUrl, dependency.GitReference)
 	_, err := git.PlainClone(installPath,
 		false,
 		&git.CloneOptions{
@@ -417,52 +556,19 @@ func (i *ModInstaller) installFromGit(dependency *ResolvedModRef, installPath st
 	return err
 }
 
-// build the path of the temp location to copy this depednency to
-func (i *ModInstaller) getDependencyTmpPath(dependencyFullName string) string {
-	return filepath.Join(i.tmpPath, dependencyFullName)
-}
-
 // build the path of the temp location to copy this depednency to
 func (i *ModInstaller) getDependencyDestPath(dependencyFullName string) string {
 	return filepath.Join(i.modsPath, dependencyFullName)
 }
 
-func (i *ModInstaller) loadDependencyMod(modVersion *versionmap.ResolvedVersionConstraint) (*modconfig.Mod, error) {
-	modPath := i.getDependencyDestPath(modconfig.ModVersionFullName(modVersion.Name, modVersion.Version))
-	modDef, err := i.loadModfile(modPath, false)
-	if err != nil {
-		return nil, err
-	}
-	if modDef == nil {
-		return nil, fmt.Errorf("failed to load mod from %s", modPath)
-	}
-	if err := i.setModDependencyPath(modDef, modPath); err != nil {
-		return nil, err
-	}
-	return modDef, nil
-
+// build the path of the temp location to copy this depednency to
+func (i *ModInstaller) getDependencyShadowPath(dependencyFullName string) string {
+	return filepath.Join(i.shadowDirPath, dependencyFullName)
 }
 
 // set the mod dependency path
-func (i *ModInstaller) setModDependencyPath(mod *modconfig.Mod, modPath string) (err error) {
-	mod.ModDependencyPath, err = filepath.Rel(i.modsPath, modPath)
-	return
-}
-
-func (i *ModInstaller) loadModfile(modPath string, createDefault bool) (*modconfig.Mod, error) {
-	if !parse.ModfileExists(modPath) {
-		if createDefault {
-			mod := modconfig.CreateDefaultMod(i.workspacePath)
-			return mod, nil
-		}
-		return nil, nil
-	}
-	mod, err := parse.ParseModDefinition(modPath)
-	if err != nil {
-		return nil, err
-	}
-
-	return mod, nil
+func (i *ModInstaller) setModDependencyConfig(mod *modconfig.Mod, dependencyPath string) error {
+	return mod.SetDependencyConfig(dependencyPath)
 }
 
 func (i *ModInstaller) updating() bool {
