@@ -23,7 +23,7 @@ func UninstallWorkspaceDependencies(ctx context.Context, opts *InstallOpts) (*In
 		return nil, err
 	}
 
-	if err := installer.UninstallWorkspaceDependencies(); err != nil {
+	if err := installer.UninstallWorkspaceDependencies(ctx); err != nil {
 		return nil, err
 	}
 
