@@ -7,6 +7,7 @@ import (
 
 	"github.com/spf13/viper"
 	"github.com/turbot/steampipe/pkg/cmdconfig"
+	"github.com/turbot/steampipe/pkg/connection_sync"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/contexthelpers"
 	"github.com/turbot/steampipe/pkg/db/db_common"
@@ -41,6 +42,7 @@ func RunBatchSession(ctx context.Context, initData *query.InitData) (int, error)
 
 	// wait for init
 	<-initData.Loaded
+
 	if err := initData.Result.Error; err != nil {
 		return 0, err
 	}
@@ -48,6 +50,13 @@ func RunBatchSession(ctx context.Context, initData *query.InitData) (int, error)
 	// display any initialisation messages/warnings
 	initData.Result.DisplayMessages()
 
+	// if there is a custom search path, wait until the first connection of each plugin has loaded
+	if customSearchPath := initData.Client.GetCustomSearchPath(); customSearchPath != nil {
+		if err := connection_sync.WaitForSearchPathSchemas(ctx, initData.Client, customSearchPath); err != nil {
+			return 0, err
+		}
+	}
+
 	failures := 0
 	if len(initData.Queries) > 0 {
 		// if we have resolved any queries, run them
@@ -104,7 +113,7 @@ func executeQuery(ctx context.Context, client db_common.Client, resolvedQuery *m
 	rowErrors := 0 // get the number of rows that returned an error
 	// print the data as it comes
 	for r := range resultsStreamer.Results {
-		rowErrors = display.ShowOutput(ctx, r, display.ShowTimingOnOutput(constants.OutputFormatTable))
+		rowErrors = display.ShowOutput(ctx, r)
 		// signal to the resultStreamer that we are done with this result
 		resultsStreamer.AllResultsRead()
 	}
