@@ -5,5 +5,7 @@ var NullHooks = &NullStatusHook{}
 type NullStatusHook struct{}
 
 func (*NullStatusHook) SetStatus(string)  {}
-func (*NullStatusHook) Done()             {}
+func (*NullStatusHook) Hide()             {}
 func (*NullStatusHook) Message(...string) {}
+func (*NullStatusHook) Show()             {}
+func (*NullStatusHook) Warn(string)       {}
