@@ -8,11 +8,13 @@ import (
 	sdkgrpc "github.com/turbot/steampipe-plugin-sdk/v5/grpc"
 	sdkproto "github.com/turbot/steampipe-plugin-sdk/v5/grpc/proto"
 	sdkplugin "github.com/turbot/steampipe-plugin-sdk/v5/plugin"
+	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/error_helpers"
+	"github.com/turbot/steampipe/pkg/pluginmanager"
+	"github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/proto"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/options"
-	"github.com/turbot/steampipe/pluginmanager"
-	"github.com/turbot/steampipe/pluginmanager_service/grpc/proto"
+	"github.com/turbot/steampipe/pkg/utils"
 )
 
 type ConnectionPluginData struct {
@@ -80,14 +82,18 @@ func NewConnectionPlugin(pluginName string, pluginClient *sdkgrpc.PluginClient,
 }
 
 // CreateConnectionPlugins instantiates plugins for specified connections, and fetches schemas
-func CreateConnectionPlugins(connectionsToCreate []*modconfig.Connection) (requestedConnectionPluginMap map[string]*ConnectionPlugin, res *RefreshConnectionResult) {
+func CreateConnectionPlugins(connectionNamesToCreate []string) (requestedConnectionPluginMap map[string]*ConnectionPlugin, res *RefreshConnectionResult) {
 	res = &RefreshConnectionResult{}
 	requestedConnectionPluginMap = make(map[string]*ConnectionPlugin)
-	if len(connectionsToCreate) == 0 {
+	if len(connectionNamesToCreate) == 0 {
 		return
 	}
-	log.Printf("[TRACE] CreateConnectionPlugin creating %d connections", len(connectionsToCreate))
+	log.Printf("[TRACE] CreateConnectionPlugin creating %d %s", len(connectionNamesToCreate), utils.Pluralize("connection", len(connectionNamesToCreate)))
 
+	var connectionsToCreate = make([]*modconfig.Connection, len(connectionNamesToCreate))
+	for i, name := range connectionNamesToCreate {
+		connectionsToCreate[i] = GlobalConfig.Connections[name]
+	}
 	// build result map, keyed by connection name
 	requestedConnectionPluginMap = make(map[string]*ConnectionPlugin, len(connectionsToCreate))
 	// build list of connection names to pass to plugin manager 'get'
@@ -116,7 +122,7 @@ func CreateConnectionPlugins(connectionsToCreate []*modconfig.Connection) (reque
 		// figure out which connections are provided by any failed plugins
 		for _, c := range connectionsToCreate {
 			if c.Plugin == failedPlugin {
-				res.AddFailedConnection(c.Name, failure)
+				res.AddFailedConnection(c.Name, constants.ConnectionErrorPluginFailedToStart)
 			}
 		}
 	}
