@@ -9,6 +9,7 @@ import (
 	"github.com/hashicorp/hcl/v2/gohcl"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
 	"github.com/hashicorp/hcl/v2/hclwrite"
+	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/ociinstaller"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
@@ -43,6 +44,14 @@ func DecodeConnection(block *hcl.Block) (*modconfig.Connection, hcl.Diagnostics)
 		}
 		connection.Type = connectionType
 	}
+	if connectionContent.Attributes["import_schema"] != nil {
+		var importSchema string
+		diags = gohcl.DecodeExpression(connectionContent.Attributes["import_schema"].Expr, nil, &importSchema)
+		if diags.HasErrors() {
+			return nil, diags
+		}
+		connection.ImportSchema = importSchema
+	}
 	if connectionContent.Attributes["connections"] != nil {
 		var connections []string
 		diags = gohcl.DecodeExpression(connectionContent.Attributes["connections"].Expr, nil, &connections)
@@ -67,6 +76,15 @@ func DecodeConnection(block *hcl.Block) (*modconfig.Connection, hcl.Diagnostics)
 				diags = append(diags, moreDiags...)
 			}
 
+			// TODO: remove in 0.21 [https://github.com/turbot/steampipe/issues/3251]
+			if connection.Options != nil {
+				diags = append(diags, &hcl.Diagnostic{
+					Severity: hcl.DiagWarning,
+					Summary:  fmt.Sprintf("%s in %s have been deprecated and will be removed in subsequent versions of steampipe", constants.Bold("'connection' options"), constants.Bold("'connection' blocks")),
+					Subject:  &connectionBlock.DefRange,
+				})
+			}
+
 		default:
 			// this can never happen
 			diags = append(diags, &hcl.Diagnostic{
