@@ -13,15 +13,15 @@ import (
 	"github.com/turbot/steampipe/pkg/db/db_local"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/filepaths"
+	"github.com/turbot/steampipe/pkg/installationstate"
 	"github.com/turbot/steampipe/pkg/plugin"
-	"github.com/turbot/steampipe/pkg/statefile"
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
 const minimumDurationBetweenChecks = 24 * time.Hour
 
 type Runner struct {
-	currentState statefile.State
+	currentState installationstate.InstallationState
 	options      *taskRunConfig
 }
 
@@ -58,6 +58,9 @@ func RunTasks(ctx context.Context, cmd *cobra.Command, args []string, options ..
 		// if the legacy file existed, then we should enforce a run, since we need
 		// to update the available version cache
 		if runner.shouldRun() || exists {
+			for _, hook := range config.preHooks {
+				hook(c)
+			}
 			runner.run(c)
 		}
 	}(ctx)
@@ -72,7 +75,7 @@ func newRunner(config *taskRunConfig) *Runner {
 	r := new(Runner)
 	r.options = config
 
-	state, err := statefile.LoadState()
+	state, err := installationstate.Load()
 	if err != nil {
 		// this error should never happen
 		// log this and carry on
@@ -159,7 +162,7 @@ func (r *Runner) shouldRun() bool {
 
 func showNotificationsForCommand(cmd *cobra.Command, cmdArgs []string) bool {
 	return !(isPluginUpdateCmd(cmd) ||
-		isPluginManagerCmd(cmd) ||
+		IsPluginManagerCmd(cmd) ||
 		isServiceStopCmd(cmd) ||
 		isBatchQueryCmd(cmd, cmdArgs) ||
 		isCompletionCmd(cmd))
@@ -171,7 +174,7 @@ func isServiceStopCmd(cmd *cobra.Command) bool {
 func isCompletionCmd(cmd *cobra.Command) bool {
 	return cmd.Name() == "completion"
 }
-func isPluginManagerCmd(cmd *cobra.Command) bool {
+func IsPluginManagerCmd(cmd *cobra.Command) bool {
 	return cmd.Name() == "plugin-manager"
 }
 func isPluginUpdateCmd(cmd *cobra.Command) bool {
