@@ -18,7 +18,7 @@ func LoadWorkspacePromptingForVariables(ctx context.Context) (*Workspace, *modco
 	workspacePath := viper.GetString(constants.ArgModLocation)
 	t := time.Now()
 	defer func() {
-		log.Printf("[TRANCE] Workspace load took %dms\n", time.Since(t).Milliseconds())
+		log.Printf("[TRACE] Workspace load took %dms\n", time.Since(t).Milliseconds())
 	}()
 	w, errAndWarnings := Load(ctx, workspacePath)
 	if errAndWarnings.GetError() == nil {
