@@ -117,7 +117,7 @@ func createShellWorkspace(workspacePath string) (*Workspace, error) {
 }
 
 // LoadResourceNames builds lists of all workspace resource names
-func LoadResourceNames(workspacePath string) (*modconfig.WorkspaceResources, error) {
+func LoadResourceNames(ctx context.Context, workspacePath string) (*modconfig.WorkspaceResources, error) {
 	utils.LogTime("workspace.LoadResourceNames start")
 	defer utils.LogTime("workspace.LoadResourceNames end")
 
@@ -134,7 +134,7 @@ func LoadResourceNames(workspacePath string) (*modconfig.WorkspaceResources, err
 		return nil, err
 	}
 
-	return workspace.loadWorkspaceResourceName()
+	return workspace.loadWorkspaceResourceName(ctx)
 }
 
 func (w *Workspace) SetupWatcher(ctx context.Context, client db_common.Client, errorHandler func(context.Context, error)) error {
@@ -255,11 +255,11 @@ func (w *Workspace) loadWorkspaceMod(ctx context.Context) *modconfig.ErrorAndWar
 	w.VariableValues = inputVariables.VariableValues
 
 	// build run context which we use to load the workspace
-	parseCtx, err := w.getParseContext()
+	parseCtx, err := w.getParseContext(ctx)
 	if err != nil {
 		return modconfig.NewErrorsAndWarning(err)
 	}
-	// add variables to runContext
+	// add variables
 	parseCtx.AddInputVariables(inputVariables)
 	// do not reload variables as we already have them
 	parseCtx.BlockTypeExclusions = []string{modconfig.BlockTypeVariable}
@@ -275,7 +275,8 @@ func (w *Workspace) loadWorkspaceMod(ctx context.Context) *modconfig.ErrorAndWar
 	m.ResourceMaps.PopulateReferences()
 	// set the mod
 	w.Mod = m
-	w.Mods = parseCtx.LoadedDependencyMods
+	// set the child mods
+	w.Mods = parseCtx.GetTopLevelDependencyMods()
 	// NOTE: add in the workspace mod to the dependency mods
 	w.Mods[w.Mod.Name()] = w.Mod
 
@@ -287,28 +288,53 @@ func (w *Workspace) loadWorkspaceMod(ctx context.Context) *modconfig.ErrorAndWar
 
 func (w *Workspace) getInputVariables(ctx context.Context, validateMissing bool) (*modconfig.ModVariableMap, error) {
 	// build a run context just to use to load variable definitions
-	variablesRunCtx, err := w.getParseContext()
+	variablesParseCtx, err := w.getParseContext(ctx)
 	if err != nil {
 		return nil, err
 	}
 
+	inputVariables, err := w.getVariableValues(ctx, variablesParseCtx, validateMissing)
+	if err != nil {
+		return nil, err
+	}
+
+	// if needed, reload
+	// if a mod require has args which use a variable, this will not have been resolved in the first pass
+	// - we need to parse again
+	if variablesParseCtx.CurrentMod.RequireHasUnresolvedArgs() {
+		// add the variables into the parse context and rebuild the eval context
+		variablesParseCtx.AddInputVariables(inputVariables)
+		variablesParseCtx.AddVariablesToEvalContext()
+
+		// now try to parse the mod again
+		inputVariables, err = w.getVariableValues(ctx, variablesParseCtx, validateMissing)
+		if err != nil {
+			return nil, err
+		}
+
+	}
+	return inputVariables, nil
+
+}
+
+func (w *Workspace) getVariableValues(ctx context.Context, variablesParseCtx *parse.ModParseContext, validateMissing bool) (*modconfig.ModVariableMap, error) {
 	// load variable definitions
-	variableMap, err := steampipeconfig.LoadVariableDefinitions(w.Path, variablesRunCtx)
+	variableMap, err := steampipeconfig.LoadVariableDefinitions(w.Path, variablesParseCtx)
 	if err != nil {
 		return nil, err
 	}
-
-	return steampipeconfig.GetVariableValues(ctx, variablesRunCtx, variableMap, validateMissing)
+	// get the values
+	return steampipeconfig.GetVariableValues(ctx, variablesParseCtx, variableMap, validateMissing)
 }
 
 // build options used to load workspace
 // set flags to create pseudo resources and a default mod if needed
-func (w *Workspace) getParseContext() (*parse.ModParseContext, error) {
+func (w *Workspace) getParseContext(ctx context.Context) (*parse.ModParseContext, error) {
 	parseFlag := parse.CreateDefaultMod
 	if w.loadPseudoResources {
 		parseFlag |= parse.CreatePseudoResources
 	}
-	workspaceLock, err := w.loadWorkspaceLock()
+	workspaceLock, err := w.loadWorkspaceLock(ctx)
 	if err != nil {
 		return nil, err
 	}
@@ -328,7 +354,7 @@ func (w *Workspace) getParseContext() (*parse.ModParseContext, error) {
 }
 
 // load the workspace lock, migrating it if necessary
-func (w *Workspace) loadWorkspaceLock() (*versionmap.WorkspaceLock, error) {
+func (w *Workspace) loadWorkspaceLock(ctx context.Context) (*versionmap.WorkspaceLock, error) {
 	workspaceLock, err := versionmap.LoadWorkspaceLock(w.Path)
 	if err != nil {
 		return nil, fmt.Errorf("failed to load installation cache from %s: %s", w.Path, err)
@@ -336,8 +362,8 @@ func (w *Workspace) loadWorkspaceLock() (*versionmap.WorkspaceLock, error) {
 
 	// if this is the old format, migrate by reinstalling dependencies
 	if workspaceLock.StructVersion() != versionmap.WorkspaceLockStructVersion {
-		opts := &modinstaller.InstallOpts{WorkspacePath: viper.GetString(constants.ArgModLocation)}
-		installData, err := modinstaller.InstallWorkspaceDependencies(opts)
+		opts := &modinstaller.InstallOpts{WorkspaceMod: w.Mod}
+		installData, err := modinstaller.InstallWorkspaceDependencies(ctx, opts)
 		if err != nil {
 			return nil, err
 		}
@@ -383,14 +409,14 @@ func (w *Workspace) loadExclusions() error {
 	return nil
 }
 
-func (w *Workspace) loadWorkspaceResourceName() (*modconfig.WorkspaceResources, error) {
+func (w *Workspace) loadWorkspaceResourceName(ctx context.Context) (*modconfig.WorkspaceResources, error) {
 	// build options used to load workspace
-	parseCtx, err := w.getParseContext()
+	parseCtx, err := w.getParseContext(ctx)
 	if err != nil {
 		return nil, err
 	}
 
-	workspaceResourceNames, err := steampipeconfig.LoadModResourceNames(w.Path, parseCtx)
+	workspaceResourceNames, err := steampipeconfig.LoadModResourceNames(w.Mod, parseCtx)
 	if err != nil {
 		return nil, err
 	}
