@@ -7,11 +7,10 @@ import {
 } from "../../../../hooks/useCheckGrouping";
 import { CheckNode } from "../common";
 import { useCallback, useEffect, useState } from "react";
-import { registerComponent } from "../../index";
 
-interface CheckGroupingProps {
+type CheckGroupingProps = {
   node: CheckNode;
-}
+};
 
 const CheckGrouping = ({ node }: CheckGroupingProps) => {
   const { dispatch, nodeStates } = useCheckGrouping();
@@ -19,13 +18,11 @@ const CheckGrouping = ({ node }: CheckGroupingProps) => {
     useState<CheckGroupNodeStates | null>(null);
 
   const expand = useCallback(() => {
-    // console.log("Capturing and expanding", nodeStates);
     setRestoreNodeStates(nodeStates);
     dispatch({ type: CheckGroupingActions.EXPAND_ALL_NODES });
   }, [dispatch, nodeStates]);
 
   const restore = useCallback(() => {
-    // console.log("Restoring", restoreNodeStates);
     if (restoreNodeStates) {
       dispatch({
         type: CheckGroupingActions.UPDATE_NODES,
@@ -48,6 +45,4 @@ const CheckGrouping = ({ node }: CheckGroupingProps) => {
   );
 };
 
-registerComponent("check_grouping", CheckGrouping);
-
 export default CheckGrouping;
