@@ -4,7 +4,6 @@ import {
   CheckDynamicColsMap,
   CheckNode,
   CheckNodeStatus,
-  CheckNodeStatusRaw,
   CheckNodeType,
   CheckResult,
   CheckSeverity,
@@ -13,12 +12,12 @@ import {
   CheckTags,
   findDimension,
 } from "./index";
+import { DashboardRunState, PanelsMap } from "../../../../types";
 import {
   LeafNodeData,
   LeafNodeDataColumn,
   LeafNodeDataRow,
 } from "../../common";
-import { PanelsMap } from "../../../../types";
 
 class Control implements CheckNode {
   private readonly _sortIndex: string;
@@ -32,7 +31,7 @@ class Control implements CheckNode {
   private readonly _results: CheckResult[];
   private readonly _summary: CheckSummary;
   private readonly _tags: CheckTags;
-  private readonly _status: CheckNodeStatusRaw;
+  private readonly _status: DashboardRunState;
   private readonly _error: string | undefined;
 
   constructor(
@@ -47,7 +46,7 @@ class Control implements CheckNode {
     data: LeafNodeData | undefined,
     summary: CheckSummary | undefined,
     tags: CheckTags | undefined,
-    status: CheckNodeStatusRaw,
+    status: DashboardRunState,
     error: string | undefined,
     panelsMap: PanelsMap,
     benchmark_trunk: Benchmark[],
@@ -73,7 +72,11 @@ class Control implements CheckNode {
     this._status = status;
     this._error = error;
 
-    if (this._status === "ready" || this._status === "started") {
+    if (
+      this._status === "initialized" ||
+      this._status === "blocked" ||
+      this._status === "running"
+    ) {
       add_control_results([this._build_control_loading_node(benchmark_trunk)]);
     } else if (this._error) {
       add_control_results([
@@ -122,8 +125,9 @@ class Control implements CheckNode {
 
   get status(): CheckNodeStatus {
     switch (this._status) {
-      case "ready":
-      case "started":
+      case "initialized":
+      case "blocked":
+      case "running":
         return "running";
       default:
         return "complete";
