@@ -1,11 +1,11 @@
 import { useEffect, useRef } from "react";
 
-const usePrevious = (value) => {
-  const ref = useRef();
+function usePrevious<T>(value: T): T {
+  const ref: any = useRef<T>();
   useEffect(() => {
     ref.current = value;
-  });
+  }, [value]);
   return ref.current;
-};
+}
 
 export default usePrevious;
