@@ -2,16 +2,22 @@ import "../utils/registerComponents";
 import Dashboard from "../components/dashboards/layout/Dashboard";
 import { buildComponentsMap } from "../components";
 import { DashboardContext } from "../hooks/useDashboard";
-import { DashboardDataModeLive, DashboardSearch } from "../types";
+import {
+  DashboardDataModeLive,
+  DashboardPanelType,
+  DashboardRunState,
+  DashboardSearch,
+} from "../types";
 import { noop } from "./func";
 import { useStorybookTheme } from "../hooks/useStorybookTheme";
 
 type PanelStoryDecoratorProps = {
   definition: any;
-  panelType: "card" | "chart" | "container" | "table" | "text";
+  panelType: DashboardPanelType;
   panels?: {
     [key: string]: any;
   };
+  status?: DashboardRunState;
   additionalProperties?: {
     [key: string]: any;
   };
@@ -26,27 +32,28 @@ export const PanelStoryDecorator = ({
   definition = {},
   panels = {},
   panelType,
+  status = "complete",
   additionalProperties = {},
 }: PanelStoryDecoratorProps) => {
   const { theme, wrapperRef } = useStorybookTheme();
   const { properties, ...rest } = definition;
 
   const newPanel = {
+    ...rest,
     name: `${panelType}.story`,
     panel_type: panelType,
-    ...rest,
     properties: {
       ...(properties || {}),
       ...additionalProperties,
     },
     sql: "storybook",
+    status,
   };
 
   return (
     <DashboardContext.Provider
       value={{
         versionMismatchCheck: false,
-        ignoreEvents: false,
         metadata: {
           mod: {
             title: "Storybook",
@@ -76,6 +83,8 @@ export const PanelStoryDecorator = ({
         },
         selectedDashboardInputs: {},
         lastChangedInput: null,
+        execution_id: null,
+        panelsLog: {},
         panelsMap: {
           [newPanel.name]: newPanel,
           ...panels,
@@ -88,10 +97,6 @@ export const PanelStoryDecorator = ({
           dashboard: "storybook.dashboard.storybook_dashboard_wrapper",
         },
 
-        sqlDataMap: {
-          storybook: definition.data,
-        },
-
         dashboardTags: {
           keys: [],
         },
@@ -120,7 +125,7 @@ export const PanelStoryDecorator = ({
         snapshotFileName: null,
       }}
     >
-      <Dashboard allowPanelExpand={false} />
+      <Dashboard showPanelControls={false} />
     </DashboardContext.Provider>
   );
 };
